@@ -21,7 +21,7 @@
 #include <tqwidget.h>
 #include <kurl.h>
 
-typedef struct RenamedList
+struct RenamedList
 {
     KURL src;
     KURL dst;
