@@ -24,9 +24,9 @@
 #include <tqcheckbox.h>
 
 // KDE includes
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
 // #include <kdebug.h>
 
@@ -35,7 +35,7 @@
 */
 class TranslitPlugin : public Plugin {
     Q_OBJECT
-  TQ_OBJECT
+  
     public:
         const TQString getName() const;
         const TQString getAccelName() const;
